pub enum FutOptChannel {
Trades,
Books,
Candles,
Aggregates,
}Expand description
FutOpt WebSocket channels
Available channels for futures and options market data streaming.
Variants
Trades- Real-time trade data (成交明細)Books- Order book depth with bid/ask levels (五檔報價)Candles- OHLCV candlestick data (K線)Aggregates- Aggregated market statistics (統計資訊)
Note
FutOpt does not have an Indices channel. The indices channel is
stock-market specific (e.g., TAIEX weighted index).
Variants
Trades
Real-time trade data (成交明細)
Books
Order book depth with bid/ask levels (五檔報價)
Candles
OHLCV candlestick data (K線)
Aggregates
Aggregated market statistics (統計資訊)
Implementations
Sourceimpl FutOptChannel
impl FutOptChannel
Sourcepub fn as_str(&self) -> &'static str
pub fn as_str(&self) -> &'static str
Get the string representation for WebSocket wire format
Example
use marketdata_core::models::futopt::FutOptChannel;
assert_eq!(FutOptChannel::Trades.as_str(), "trades");
assert_eq!(FutOptChannel::Books.as_str(), "books");
assert_eq!(FutOptChannel::Candles.as_str(), "candles");
assert_eq!(FutOptChannel::Aggregates.as_str(), "aggregates");Trait Implementations
Sourceimpl Clone for FutOptChannel
impl Clone for FutOptChannel
Sourcefn clone(&self) -> FutOptChannel
fn clone(&self) -> FutOptChannel
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for FutOptChannel
impl Debug for FutOptChannel
Sourceimpl<'de> Deserialize<'de> for FutOptChannel
impl<'de> Deserialize<'de> for FutOptChannel
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<FutOptChannel, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<FutOptChannel, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Display for FutOptChannel
impl Display for FutOptChannel
Sourceimpl Hash for FutOptChannel
impl Hash for FutOptChannel
Sourceimpl PartialEq for FutOptChannel
impl PartialEq for FutOptChannel
Sourcefn eq(&self, other: &FutOptChannel) -> bool
fn eq(&self, other: &FutOptChannel) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for FutOptChannel
impl Serialize for FutOptChannel
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
impl Copy for FutOptChannel
impl Eq for FutOptChannel
impl StructuralPartialEq for FutOptChannel